<?php
require_once __DIR__ . DIRECTORY_SEPARATOR . "includes" . DIRECTORY_SEPARATOR . "helpers.php";
require_once __DIR__ . DIRECTORY_SEPARATOR . "classes" . DIRECTORY_SEPARATOR . "ModuleHistoryController.php";
require_once __DIR__ . DIRECTORY_SEPARATOR . "classes" . DIRECTORY_SEPARATOR . "DoseController.php";

$authentication = new Authentication();
$authentication->CheckAuthentication();

SetTimeZone();

$role = $_SESSION["role"];

if(!$authentication->HasAccess($role , Modules::DOSE_ORDERS) &&
   !$authentication->HasAccess($role , Modules::PHARMACY))
    $authentication->DenyAccess();

$can_export = $authentication->CanExport($role , Modules::DOSE_ORDERS);
$can_delete = $authentication->CanDelete($role , Modules::DOSE_ORDERS);

global $DoseController;
$validation = new Validation();

$status_id = "";
if(isset($_GET["status"])){
    $status_id = $_GET["status"];
    if($status_id != "All")
        $validation->ValidateNumericParameter($status_id);
}

$filter_id = $validation->GetNumericParameterOrDefault('filter', '1');
$st_id = $validation->GetNumericParameterOrDefault('id', $_SESSION["store_id"]);
$qtyLeft = $validation->GetNumericParameterOrDefault('qtyLeft', '');
$pharmacy_mode = false;

if(isset($_GET['doctorlistview'])){
    $doctorListView = "all"; //$_GET['doctorlistview'];
    $pageTitle = "Doctor List View";
    $doseOrderJoinType = "INNER JOIN";
    $status_id = "All";
    $can_export = false; // exporting is not implemented in this mode yet

    $pharmacy_mode =  $authentication->CanWrite($role , Modules::PHARMACY);
} else {
    $doctorListView = "none";
    $pageTitle = "Dose Orders";
    $doseOrderJoinType = "LEFT OUTER JOIN ";
    $filter_id = "3"; // equals to "all" mode - effectively disabling the filter
    $pharmacy_mode = false; // override this to false so we never enter it
}

$filterDate = "";
$dt1 = "";
$dt2 = "";
if (isset($_GET['startdate']) && isset($_GET['enddate'])) {
    $dt1 = $_GET['startdate'];
    $dt2 = $_GET['enddate'];

    $validation->ValidateDateParameter($dt1);
    $validation->ValidateDateParameter($dt2);

    $start_dt = date('Y-m-d', strtotime($dt1));
    $end_dt = date('Y-m-d', strtotime($dt2));
    $filterDate = " BETWEEN '$start_dt' AND '$end_dt'";
} else {
    $start_dt = date("Y-m-d", strtotime('first day of this month'));
    $end_dt = date("Y-m-d", strtotime("last day of this month"));

    $filterDate = " BETWEEN '$start_dt' AND '$end_dt'";
}

$showAllStores = isset($_GET['showAllStores']);
$uid = $_SESSION["userid"];

?>
<!DOCTYPE html>
<!-- 
Template Name: Metronic - Responsive Admin Dashboard Template build with Twitter Bootstrap 3.0
Version: 1.5
Author: KeenThemes
Website: http://www.keenthemes.com/
Purchase: http://themeforest.net/item/metronic-responsive-admin-dashboard-template/4021469?ref=keenthemes
-->
<!--[if IE 8]>
<html lang="en" class="ie8 no-js"> <![endif]-->
<!--[if IE 9]>
<html lang="en" class="ie9 no-js"> <![endif]-->
<!--[if !IE]><!-->
<html lang="en" class="no-js"> <!--<![endif]-->
<!-- BEGIN HEAD -->
<head>
    <meta charset="utf-8"/>
    <title><?php echo $pageTitle; ?></title>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta content="width=device-width, initial-scale=1.0" name="viewport"/>
    <meta content="" name="description"/>
    <meta content="" name="author"/>
    <meta name="MobileOptimized" content="320">
    <!-- BEGIN GLOBAL MANDATORY STYLES -->
    <link href="assets/plugins/font-awesome/css/font-awesome.min.css" rel="stylesheet" type="text/css"/>
    <link href="assets/plugins/bootstrap/css/bootstrap.min.css" rel="stylesheet" type="text/css"/>
    <link href="assets/plugins/uniform/css/uniform.default.css" rel="stylesheet" type="text/css"/>
    <!-- END GLOBAL MANDATORY STYLES -->
    <!-- BEGIN PAGE LEVEL STYLES -->
    <link rel="stylesheet" type="text/css" href="assets/plugins/select2/select2_metro.css"/>
    <link rel="stylesheet" href="assets/plugins/data-tables/DT_bootstrap.css"/>
    <!-- END PAGE LEVEL SCRIPTS -->
    <!-- BEGIN THEME STYLES -->
    <link href="assets/css/style-metronic.css" rel="stylesheet" type="text/css"/>
    <link href="assets/css/style.css" rel="stylesheet" type="text/css"/>
    <link href="assets/css/style-responsive.css" rel="stylesheet" type="text/css"/>
    <link href="assets/css/plugins.css" rel="stylesheet" type="text/css"/>
    <link href="assets/css/themes/default.css" rel="stylesheet" type="text/css" id="style_color"/>
    <link href="assets/css/custom.css" rel="stylesheet" type="text/css"/>
    <!-- END THEME STYLES -->
    <link rel="shortcut icon" href="favicon.ico"/>
</head>

<!-- END HEAD -->
<!-- BEGIN BODY -->
<body class="page-header-fixed">
<!-- BEGIN HEADER -->
<div class="header navbar navbar-inverse navbar-fixed-top">
    <!-- BEGIN TOP NAVIGATION BAR -->
    <div class="header-inner">
        <!-- BEGIN LOGO -->
        <a class="navbar-brand" href="#">
            POS SYSTEM
        </a>
        <!-- END LOGO -->
        <!-- BEGIN RESPONSIVE MENU TOGGLER -->
        <a href="javascript:;" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            <img src="assets/img/menu-toggler.png" alt=""/>
        </a>
        <!-- END RESPONSIVE MENU TOGGLER -->
        <!-- BEGIN TOP NAVIGATION MENU -->
        <ul class="nav navbar-nav pull-right">
            <!-- BEGIN NOTIFICATION DROPDOWN -->
            <li class="dropdown" id="header_notification_bar">
                <a href="index.php" class="dropdown-toggle">
                    Logout
                </a>
            </li>
        </ul>
    </div>
</div>
<!-- END HEADER -->
<div class="clearfix"></div>
<!-- BEGIN CONTAINER -->
<div class="page-container">
<?php include('menu.php'); ?>
<!-- END SIDEBAR -->
<!-- BEGIN PAGE -->
<div class="page-content">
    <!-- BEGIN SAMPLE PORTLET CONFIGURATION MODAL FORM-->

    <!-- /.modal -->
    <!-- END SAMPLE PORTLET CONFIGURATION MODAL FORM-->
    <!-- BEGIN STYLE CUSTOMIZER -->

    <!-- END BEGIN STYLE CUSTOMIZER -->
    <!-- BEGIN PAGE HEADER-->
    <div class="row">
        <div class="col-md-12">
            <!-- BEGIN PAGE TITLE & BREADCRUMB-->
            <div class="table-toolbar pull-right">
                <?php if($can_export){ ?>
                    <a class="btn btn-lg green hidden-print"
                       href="<?php echo "dose_active_orders_export.php?status=$status_id&id=$st_id&qtyLeft=$qtyLeft"
                           . ($showAllStores ? "&showAllStores=1" : "")
                           . (($dt1 != "" && $dt2 != "") ? "&startdate=$dt1&enddate=$dt2" : ""); ?>">Export <i class="icon-print"></i>
                    </a>
                <?php } ?>
            </div>

            <h3 class="page-title">
                <?php echo $pageTitle; ?>
            </h3>
            <!-- END PAGE TITLE & BREADCRUMB-->
        </div>
    </div>
    <div class="row">
        <div class="col-md-12">
            <div class="form-group">
                <label class="control-label col-md-3">Change Store</label>

                <div class="col-md-3">
                    <select name="changestore" class="form-control" id="changestore">
                        <option <?php if ('0' == $st_id) echo "selected=selected"; ?> value="0">All Stores</option>
                        <?php
                        $sql = "select * from stores_master s inner join emp_store e on s.store_id=e.store_id WHERE e.emp_id=$_SESSION[userid]";
                        if (!$showAllStores)
                            $sql .= " and status=0";

                        $quer = mysql_query($sql);
                        while ($r = mysql_fetch_array($quer)) {
                            ?>
                            <option value="<?php echo $r['store_id']; ?>"
                                <?php if ($r['store_id'] == $st_id) echo "selected=selected"; ?>
                                ><?php echo $r['store_name']; ?></option>
                        <?php } ?>
                    </select>
                </div>
                <div class="col-md-3">
                    <input type="checkbox" id="chkShowAllStores" <?php if ($showAllStores) echo "checked=true"; ?> />
                    <label class="control-label" for="chkShowAllStores">Show Inactive Stores</label>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-md-12">
            <div class="form-group">
                <label class="control-label col-md-3">Date Range</label>

                <div class="col-md-3">
                    <input class="form-control form-control-inline input-medium date-picker" id="dt" size="16"
                           type="text" placeholder="Start Date" value="" style="cursor:pointer">
                </div>
                <div class="col-md-3">
                    <input class="form-control form-control-inline input-medium date-picker" id="dt1" size="16"
                           type="text" placeholder="End Date" value="" style="cursor:pointer">
                </div>
            </div>
        </div>
    </div>
    <?php if($doctorListView == "none") {?>
    <div class="row">
        <div class="col-md-12">
            <div class="form-group">
                <label class="control-label col-md-3" for="changestatus">Select Status</label>

                <div class="col-md-3">
                    <select name="changestatus" class="form-control" id="changestatus">
                        <option <?php if ('' == $status_id) echo "selected=selected"; ?> value="">Active Orders</option>
                        <?php

                        foreach($DoseController->Statuses as $key=>$value)
                            if($key != null) {
                            ?>
                            <option <?php if ($status_id == $key) echo "selected=selected"; ?>
                                value="<?php echo $key; ?>"><?php echo $value; ?></option>
                        <?php } ?>
                        <option <?php if ('All' == $status_id) echo "selected=selected"; ?> value="All">All Orders</option>
                    </select>
                </div>
            </div>
        </div>
    </div>
    <?php } else if(!$pharmacy_mode){ ?>
    <div class="row">
        <div class="col-md-12">
            <div class="form-group">
                <label class="control-label col-md-3" for="changefilter">Select Filter</label>

                <div class="col-md-3">
                    <select name="changefilter" class="form-control" id="changefilter">
                        <option <?php if ('1' == $filter_id) echo "selected=selected"; ?> value="1">New Orders</option>
                        <option <?php if ('2' == $filter_id) echo "selected=selected"; ?> value="2">Existing Orders</option>
                        <option <?php if ('3' == $filter_id) echo "selected=selected"; ?> value="3">All Orders</option>
                    </select>
                </div>
            </div>
        </div>
    </div>
    <?php } ?>
    <br/>
    <div class="row">
        <div class="col-md-12">
            <div class="form-group">
                <label class="control-label col-md-3" for="qtyLeft">Qty left is less than</label>

                <div class="col-md-5">
                    <input type="text" name="qtyLeft" id="qtyLeft" class="form-control" value="<?php echo $qtyLeft; ?>" />
                </div>
                <button class="btn blue" id="btnApply" >Apply</button>
            </div>
        </div>
    </div>
    <br/>
    <!-- END PAGE HEADER-->
    <!-- BEGIN PAGE CONTENT-->
    <div class="row">
        <div class="col-md-12">

            <!-- Modal Windows Go Here -->

            <div class="portlet box blue">
                <div class="portlet-title">
                    <div class="caption"><i class="icon-edit"></i>Dose Orders</div>
                </div>

                <div class="portlet-body">
                    <div class="table-toolbar">
                        <div class="btn-group">
                            <a id="sample_editable_1_new1" href='dose_add_order.php' class="btn green">
                                Add New <i class="icon-plus"></i>
                            </a>
                        </div>
                    </div>

                    <table class="table table-striped table-hover table-bordered" id="sample_editable_1">
                        <thead>
                        <tr>
                            <th>Invoice #</th>
                            <th>Order Date</th>
                            <th>Last Update</th>
                            <th>Customer Name &amp; Phone</th>
                            <th>Product Name</th>
                            <th>Included</th>
                            <th>Used</th>
                            <th>Left</th>
                            <th>Ordered</th>
                            <th>Status</th>
                            <?php if($doctorListView != "none") {?>
                                <th>Prescriptions</th>
                            <?php } ?>
                            <?php if($doctorListView == "none") {?>
                            <th>Edit/Add</th>
                            <?php } ?>
                            <?php if($can_delete) { ?>
                                <th>Delete</th>
                            <?php } ?>

                        </tr>
                        </thead>
                        <p id="dynamic_pager_content2">
                            <tbody>
                            <?php

                            $filter = "";
                            $join = " WHERE ";
     
							$doseStoreFilter = "";
							$storeFilter = "";
							
							if($st_id != 0) {
								$doseStoreFilter = " WHERE (store_id = $st_id OR store_id IS NULL)";
								$storeFilter = " AND it.store_id = $st_id";
							} else {
                                if($showAllStores) {
                                    $doseStoreFilter = " WHERE (store_id in (select store_id from emp_store where emp_id = $uid) OR store_id IS NULL)";
                                    $storeFilter = " AND (it.store_id in (select store_id from emp_store where emp_id = $uid))";
                                }
                                else
                                {
                                    $doseStoreFilter = " WHERE (store_id in (select e.store_id from stores_master s inner join emp_store e on s.store_id=e.store_id WHERE e.emp_id = $uid and status=0) OR store_id IS NULL)";
                                    $storeFilter = " AND it.store_id in (select e.store_id from stores_master s inner join emp_store e on s.store_id=e.store_id WHERE e.emp_id = $uid and status=0)";
                                }
                            }
							
                            if($status_id == "") {
                                $filter .= " $join (((d.status<>2) AND (d.status < 5) or d.status is null))"; // all that are NOT delivered and active will be displayed
                                $join = " AND ";
                            }  else {
                                if ($status_id != "All") {
                                    $filter .= " $join d.status=$status_id";
                                    $join = " AND ";
                                }
                            }

                            if($pharmacy_mode) {
                                $filter .= " $join NOT p.id is null AND p.pharmacy_id = " . $_SESSION["userid"];
                                $join = " AND ";
                            } else if($filter_id != "3") {
                                if($filter_id == "1") { // New Orders
                                    $filter .= " $join p.id is null";
                                } else {
                                    $filter .= " $join NOT p.id is null";
                                }
                                $join = " AND ";
                            }

                            $sql = "SELECT
                                COUNT(*)
                            FROM
                                invoice_total it
                                INNER JOIN invoice i ON
                                    it.`id` = i.`invoice_id`
                                INNER JOIN inventory inv ON
                                    i.`item_id` = inv.`id`
                                INNER JOIN contacts c ON
                                    it.contact_id = c.`id`
                                $doseOrderJoinType (SELECT * FROM dose_order_details $doseStoreFilter) d ON
                                    d.`contact_id` = it.contact_id AND d.`inventory_id` = inv.`id` AND d.`invoice_id` = it.`id`
                                LEFT JOIN
                                    prescriptions p
                                ON
                                    d.`id` = p.`id`
                               $filter AND
                                    (d.ordered_date $filterDate OR d.ordered_date IS NULL) AND
                                    NOT (inv.`dose` * i.`quantity`) IS NULL
                                $storeFilter";

                            $query = mysql_query($sql);
                            $num = mysql_fetch_array($query);
                            $num = $num[0];

                            $a = 0;
                            $b = 20;
                            $pagenum = 1;

                            if (isset($_GET['from']) && isset($_GET['to'])) {
                                $a = $_GET['from'];
                                $b = $_GET['to'];
                                $pagenum = $_GET['page'];
                            }

                            $sql = "
                            SELECT
                                it.`id`,
                                it.`invoice_num`,
                                c.id AS contact_id,
                                c.fname,
                                c.lname,
                                c.phone,
                                inv.`dose` * SUM(i.`quantity`) AS purchased_doses,
                                IFNULL(SUM(d.`amount`), 0) AS ordered_doses,
                                IFNULL(SUM(d.`left`), 0) AS left_doses,
                                IFNULL((SELECT SUM(`amount`)
                                        FROM dose_lastorder
                                        WHERE  dose_lastorder.`store_id` = it.`store_id` AND dose_lastorder.`invoice_id` = it.id AND `inventory_id` = inv.`id` AND dose_lastorder.`status` <> 6), 0) total_ordered_doses,
                                inv.`dose`,
                                i.`item_id`,
                                SUM(i.`quantity`) AS total_quantity,
                                inv.`name`,
                                d.status,
                                d.id AS order_id,
                                d.ordered_date,
                                d.modified_date,
	                            IFNULL(p.id,-1) AS prescription_id
                            FROM
                                invoice_total it
                            INNER JOIN
                                invoice i
                            ON
                                it.`id` = i.`invoice_id`
                            INNER JOIN
                                inventory inv
                            ON
                                i.`item_id` = inv.`id`
                            INNER JOIN
                                contacts c
                            ON
                                it.contact_id = c.`id`
                            $doseOrderJoinType
                                (SELECT * FROM dose_order_details $doseStoreFilter) d
                            ON
                                d.`contact_id` = it.contact_id AND d.`inventory_id` = inv.`id` AND d.`invoice_id` = it.`id`
                            LEFT JOIN
                                prescriptions p
                            ON
                              d.`id` = p.`id`
                            $filter
                            GROUP BY
                                it.`id`, it.`invoice_num`, c.id, c.fname, c.lname, c.phone, inv.`dose`, inv.`name`, d.status, order_id, it.store_id
                            HAVING
                                NOT purchased_doses IS NULL
                            AND
                                (d.ordered_date $filterDate OR d.ordered_date IS NULL)
                            $storeFilter limit $a,$b";

                            if($qtyLeft != "")
                                $sql .= " AND left_doses < $qtyLeft";

                            //echo $sql;

                            $query = mysql_query($sql);
                            while ($row = mysql_fetch_array($query)) {
                                ?>
                                <tr>
                                    <td>
                                        <a href="viewinvoice.php?id=<?php echo $row['id']; ?>">#<?php echo $row['invoice_num']; ?></a>
                                    </td>
                                    <td><?php echo $row['ordered_date']==null ? "" : date('m/d/Y h:iA', strtotime($row['ordered_date'])); ?></td>
                                    <td><?php echo $row['modified_date']==null ? "" : date('m/d/Y h:iA', strtotime($row['modified_date'])); ?></td>
                                    <td>
                                        <a href="editcontact.php?id=<?php echo $row['contact_id']; ?>"><?php echo $row['lname'] . ', ' . $row['fname'] . ' - ' . $row['phone']; ?></a>
                                    </td>
                                    <td><?php echo $row['name']; ?></td>
                                    <td><?php echo $row['purchased_doses']; ?></td>
                                    <td><?php echo $row['ordered_doses']; ?></td>
                                    <td><?php echo $row['left_doses']; ?></td>
                                    <td><?php echo $row['total_ordered_doses']; ?></td>
                                    <td><?php echo $DoseController->Statuses[$row['status']]; ?></td>
                                    <?php if($doctorListView != "none"){ ?>
                                        <td>
                                            <?php if($row['prescription_id'] == -1){
                                                echo "<a href='editprescription.php?id=$row[order_id]'>Add New</a>";
                                            }
                                            else
                                            {
                                                echo "<a href='editprescription.php?id=$row[prescription_id]'>Edit</a>";
                                            }
                                            ?>
                                        </td>
                                    <?php
                                    }
                                    else
                                    { ?>
                                    <td><?php
                                        if($row['order_id'] != null){
                                            echo "<a href='dose_add_order.php?id=$row[order_id]'>Edit</a> |";
                                        }
                                        echo "<a href='dose_add_order.php?inv=$row[id]&iid=$row[item_id]'>Add New</a>";
                                        ?></td>
                                    <?php } ?>

                                    <?php if($can_delete) { ?>
                                        <td>
                                            <?php if($doctorListView == "none" || $row['prescription_id'] != -1){ ?>
                                            <a class='delete' data-id='<?php echo $row['order_id']; ?>' href='javascript:;'>Delete</a>
                                            <?php } ?>
                                        </td>
                                    <?php } ?>

                                </tr>
                            <?php } ?>

                            </tbody>
                        </p>
                    </table>


                </div>

            </div>

        </div>
        <div style="float: right;">
            <h4 class="block">Advanced Pagination</h4>

            <p id="dynamic_pager_demo21"></p>
        </div>

        <!-- END PAGE CONTENT-->
    </div>
    <!-- END PAGE -->
</div>

<!-- END CONTAINER -->
<!-- BEGIN FOOTER -->
<div class="footer">
    <div class="footer-inner">
        2013 &copy; Metronic by keenthemes.
    </div>
    <div class="footer-tools">
         <span class="go-top">
         <i class="icon-angle-up"></i>
         </span>
    </div>
</div>

<!-- END FOOTER -->
<!-- BEGIN JAVASCRIPTS(Load javascripts at bottom, this will reduce page load time) -->
<!-- BEGIN CORE PLUGINS -->
<!--[if lt IE 9]>
<script src="assets/plugins/respond.min.js"></script>
<script src="assets/plugins/excanvas.min.js"></script>
<![endif]-->
<script src="assets/plugins/jquery-1.10.2.min.js" type="text/javascript"></script>
<script src="assets/plugins/jquery-migrate-1.2.1.min.js" type="text/javascript"></script>
<!-- IMPORTANT! Load jquery-ui-1.10.1.custom.min.js before bootstrap.min.js to fix bootstrap tooltip conflict with jquery ui tooltip -->
<script src="assets/plugins/jquery-ui/jquery-ui-1.10.3.custom.min.js" type="text/javascript"></script>
<script src="assets/plugins/bootstrap/js/bootstrap.min.js" type="text/javascript"></script>
<script src="assets/plugins/bootstrap-hover-dropdown/twitter-bootstrap-hover-dropdown.min.js"
        type="text/javascript"></script>
<script src="assets/plugins/jquery-slimscroll/jquery.slimscroll.min.js" type="text/javascript"></script>
<script src="assets/plugins/jquery.blockui.min.js" type="text/javascript"></script>
<script src="assets/plugins/jquery.cookie.min.js" type="text/javascript"></script>
<script src="assets/plugins/uniform/jquery.uniform.min.js" type="text/javascript"></script>
<!-- END CORE PLUGINS -->
<!-- BEGIN PAGE LEVEL PLUGINS -->
<script type="text/javascript" src="assets/plugins/jquery-multi-select/js/jquery.quicksearch.js"></script>
<script type="text/javascript" src="assets/plugins/select2/select2.min.js"></script>
<script type="text/javascript" src="assets/plugins/jquery-inputmask/jquery.inputmask.bundle.min.js"></script>
<script type="text/javascript" src="assets/plugins/jquery-multi-select/js/jquery.quicksearch.js"></script>

<script type="text/javascript" src="assets/plugins/data-tables/jquery.dataTables.js"></script>
<script type="text/javascript" src="assets/plugins/data-tables/DT_bootstrap.js"></script>
<script type="text/javascript" src="assets/plugins/bootstrap-datepicker/js/bootstrap-datepicker.js"></script>
<script type="text/javascript" src="assets/plugins/bootstrap-datetimepicker/js/bootstrap-datetimepicker.js"></script>
<script type="text/javascript" src="assets/plugins/jquery-bootpag/jquery.bootpag.min.js"></script>
<!-- END PAGE LEVEL PLUGINS -->
<!-- BEGIN PAGE LEVEL SCRIPTS -->
<script src="assets/scripts/app.js"></script>
<script src="assets/scripts/table-editable.js"></script>
<script src="assets/scripts/ui-general.js"></script>

<!-- END PAGE LEVEL SCRIPTS -->
<script>
    jQuery(document).ready(function () {
        App.init();
        //  TableEditable.init();
        UIGeneral.init();

//        $('#dose_table').dataTable({"aaSorting": [[2, 'desc']]}).fnDraw();
    });

    $('#changestore').change(function () {
        location.href = buildUrl();;
    });

    $('#changestatus').change(function () {
        location.href = buildUrl();
    });

    $('#changefilter').change(function () {
        location.href = buildUrl();
    });

    $('#chkShowAllStores').change(function () {
        location.href = buildUrl();
    });

    $('#btnApply').click(function () {
        location.href = buildUrl();
    });

    function buildUrl(){
        var store = $('#changestore').val();
        var status = $('#changestatus').val();
        var filter = $('#changefilter').val();
        var qtyLeft = $('#qtyLeft').val();

        var showAllStores = $('#chkShowAllStores')[0].checked;
        var a = $('#dt').val();
        var b = $('#dt1').val();

        var url = "?id=" + store;
        if(showAllStores)
            url += "&showAllStores=1";
        if(status != '' && status != undefined)
            url += "&status="+status;
        if(filter != '' && filter != undefined)
            url += "&filter="+filter;
        if(qtyLeft != '')
            url += "&qtyLeft="+qtyLeft;

        if(a!= "" && b != "")
            url += '&startdate=' + a + '&enddate=' + b;
<?php
    if($doctorListView == "none") {
        echo "return 'dose_active_orders.php' +  url;";
    }
    else{
        echo "return 'dose_active_orders.php' + url + '&doctorlistview=$doctorListView';";
    }

?>
    }

    $('#dt').datepicker({
        startDate: "2014-01-01"
    });

    $('#dt1').datepicker({
        startDate: "2014-01-01"
    });

    <?php
     if (isset($_GET['startdate'])) { ?>
    $('#dt').data().datepicker.setDate(new Date('<?php echo $_GET['startdate']; ?>'))
    $('#dt').data().datepicker.update();
    <?php }
    if (isset($_GET['enddate'])) { ?>
    $('#dt1').data().datepicker.setDate(new Date('<?php echo $_GET['enddate']; ?>'))
    $('#dt1').data().datepicker.update();
    <?php } ?>


    $('#dt1').change(function () {
        location.href = buildUrl();
    });


    $('.delete').click(function () {
        var r = confirm("Are you sure you want to delete this record?");
        if (r) {
            var order_id = $(this).data('id');
            $.ajax({
                type: 'POST',
                dataType: "json",
                data: {order_id: order_id},
                url: '<?php echo ($doctorListView == "none") ? "dose_delete_orders.php" : "prescription_delete.php"; ?>',
                success: function (data) {
                    location.href = buildUrl();
                },
                error: function (e,r) {
                    event.stopPropagation();
                }
            });
        } else {
            event.stopPropagation();
        }
    });
</script>

<script>
    var id = <?php echo $num; ?>;
    var pagenum = <?php echo $pagenum; ?>;
    var id1 = Math.ceil(id / 20);

    $('#dynamic_pager_demo21').bootpag({
        paginationClass: 'pagination pagination-sm',
        next: '<icon class="icon-angle-right"></i>',
        prev: '<icon class="icon-angle-left"></i>',
        total: id1,
        page: pagenum,
        maxVisible: 6
    }).on('page', function (event, num) {
        var a = (num - 1) * 20;
        var b = 20;
        location.href = "dose_active_orders.php?from=" + a + "&to=" + b + "&page=" + num;
        //$("#dynamic_pager_content2").html("Page " + num + " content here"); // or some ajax content loading...
    });

    $('#sample_editable_1').dataTable({
        "bPaginate": false,
        "bFilter": false
    });
</script>

<!-- END JAVASCRIPTS -->
</body>
<!-- END BODY -->
</html>